@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.805';
+our $VERSION = '1.806';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -249,7 +249,7 @@ sub run (&@) {
    my $_r = ref $_[0];
 
    if ($_r eq 'ARRAY' || $_r eq 'CODE' || $_r eq 'GLOB' || $_r eq 'SCALAR' || $_r =~ /^IO::/) {
-      $_input_data = shift;
+      $_input_data = shift if (@_ == 1);
    }
 
    if (defined (my $_p = $_params->{$_pid})) {
@@ -449,7 +449,7 @@ MCE::Map - Parallel map model similar to the native map function
 
 =head1 VERSION
 
-This document describes MCE::Map version 1.805
+This document describes MCE::Map version 1.806
 
 =head1 SYNOPSIS
 
